@@ -6,6 +6,7 @@ import click
 from . import __version__
 from .github import git
 from .kong import kong
+from .utils import niceJson
 
 AGILE_CONFIG = os.environ.get("AGILE_CONFIG", "agile.json")
 
@@ -15,6 +16,9 @@ AGILE_CONFIG = os.environ.get("AGILE_CONFIG", "agile.json")
     "--debug/--no-debug", is_flag=True, default=False, help="Run in debug mode"
 )
 @click.option("--version", is_flag=True, default=False, help="Display version and exit")
+@click.option(
+    "--show-config", is_flag=True, default=False, help="Display config and exit"
+)
 @click.option(
     "--config",
     default=AGILE_CONFIG,
@@ -22,7 +26,9 @@ AGILE_CONFIG = os.environ.get("AGILE_CONFIG", "agile.json")
     help=f"Agile configuration json file location ({AGILE_CONFIG})",
 )
 @click.pass_context
-def start(ctx, debug, version, config):
+def start(
+    ctx: click.Context, debug: bool, version: bool, show_config: bool, config: str
+):
     """Commands for devops operations"""
     ctx.obj = {}
     ctx.DEBUG = debug
@@ -32,8 +38,11 @@ def start(ctx, debug, version, config):
     else:
         agile = {}
     ctx.obj["agile"] = agile
-    if version:
-        click.echo(__version__)
+    if version or show_config:
+        if version:
+            click.echo(__version__)
+        if show_config:
+            click.echo(niceJson(agile))
         ctx.exit(0)
     if not ctx.invoked_subcommand:
         click.echo(ctx.get_help())
